use algpath::{
    reckless::{self, complex, Cif, Rif},
    traits::interval,
};
use criterion::{black_box, criterion_group, criterion_main, BatchSize, BenchmarkId, Criterion};
use rand::Rng;

pub fn mul(c: &mut Criterion) {
    let mut rng = rand::rng();

    c.bench_function("Rif mul", |b| {
        b.iter_batched(
            || (rng.random(), rng.random()),
            |(i, j): (Rif, Rif)| i * j,
            BatchSize::SmallInput,
        )
    });

    c.bench_function("Rif mul unchecked", |b| {
        b.iter_batched(
            || (rng.random(), rng.random()),
            |(i, j): (Rif, Rif)| Rif::_mul(i, j),
            BatchSize::SmallInput,
        )
    });

    c.bench_function("Cif mul", |b| {
        b.iter_batched(
            || (rng.random(), rng.random()),
            |(i, j): (Cif, Cif)| i * j,
            BatchSize::SmallInput,
        )
    });

    c.bench_function("Cif mul unchecked", |b| {
        b.iter_batched(
            || (rng.random(), rng.random()),
            |(i, j): (Cif, Cif)| reckless::complex::arith::_mul(i, j),
            BatchSize::SmallInput,
        )
    });
}

criterion_group!(benches, mul);
criterion_main!(benches);
